.. SPDX-FileCopyrightText: 2024 Anna <cyber@sysrq.in>
.. SPDX-License-Identifier: WTFPL
.. No warranty.

gentle.metadata
===============

.. autosummary::
   :toctree: metadata

   gentle.metadata.types
   gentle.metadata.utils

.. automodule:: gentle.metadata
   :members:
